[libgda] Introspection improvements



commit 222af3513d78ae0fd39fee47c2b1e5daa86dd722
Author: Vivien Malerba <malerba gnome-db org>
Date:   Sat Sep 3 22:21:23 2011 +0200

    Introspection improvements

 libgda/Makefile.am                            |    3 ++-
 libgda/gda-data-model-bdb.c                   |    2 +-
 libgda/gda-data-model-ldap.c                  |    2 +-
 libgda/gda-data-select.c                      |    2 +-
 libgda/gda-sql-builder.c                      |   18 +++++++++---------
 libgda/gda-util.c                             |    8 ++++----
 libgda/handlers/gda-handler-time.c            |    6 +++---
 libgda/sql-parser/gda-statement-struct-decl.h |   14 +++++++-------
 8 files changed, 28 insertions(+), 27 deletions(-)
---
diff --git a/libgda/Makefile.am b/libgda/Makefile.am
index 7225896..bce3d9d 100644
--- a/libgda/Makefile.am
+++ b/libgda/Makefile.am
@@ -312,7 +312,8 @@ threadwrapper = \
 
 sqlparser = \
 	sql-parser/gda-sql-parser.h \
-	sql-parser/gda-sql-parser.c
+	sql-parser/gda-sql-parser.c \
+	sql-parser/gda-statement-struct-decl.h
 
 handlers = \
 	handlers/gda-handler-bin.h \
diff --git a/libgda/gda-data-model-bdb.c b/libgda/gda-data-model-bdb.c
index 22658b4..e43e027 100644
--- a/libgda/gda-data-model-bdb.c
+++ b/libgda/gda-data-model-bdb.c
@@ -468,7 +468,7 @@ gda_data_model_bdb_get_property (GObject *object,
  * Creates a new #GdaDataModel object to access the contents of the Berkeley DB file @file,
  * for the database @db_name if not %NULL
  *
- * Returns: a new #GdaDataModel
+ * Returns: (transfer full): a new #GdaDataModel
  */
 GdaDataModel *
 gda_data_model_bdb_new (const gchar *filename, const gchar *db_name)
diff --git a/libgda/gda-data-model-ldap.c b/libgda/gda-data-model-ldap.c
index 792534a..074cd05 100644
--- a/libgda/gda-data-model-ldap.c
+++ b/libgda/gda-data-model-ldap.c
@@ -197,7 +197,7 @@ gda_data_model_ldap_get_type (void)
  * In case of multi valued attributes, an error will be returned when trying to read the attribute:
  * gda_data_model_iter_get_value_at() will return %NULL when using an iterator.
  *
- * Returns: a new #GdaDataModel
+ * Returns: (transfer full): a new #GdaDataModel
  *
  * Since: 4.2.8
  */
diff --git a/libgda/gda-data-select.c b/libgda/gda-data-select.c
index 39833b4..23cb47c 100644
--- a/libgda/gda-data-select.c
+++ b/libgda/gda-data-select.c
@@ -1483,7 +1483,7 @@ row_selection_condition_foreach_func (GdaSqlAnyPart *part, G_GNUC_UNUSED gpointe
 }
 
 /**
- * gda_data_select_set_row_selection_condition:
+ * gda_data_select_set_row_selection_condition: (skip)
  * @model: a #GdaDataSelect data model
  * @expr: (transfer none): a #GdaSqlExpr expression
  * @error: a place to store errors, or %NULL
diff --git a/libgda/gda-sql-builder.c b/libgda/gda-sql-builder.c
index d581cc2..526f385 100644
--- a/libgda/gda-sql-builder.c
+++ b/libgda/gda-sql-builder.c
@@ -352,7 +352,7 @@ gda_sql_builder_get_statement (GdaSqlBuilder *builder, GError **error)
 }
 
 /**
- * gda_sql_builder_get_sql_statement:
+ * gda_sql_builder_get_sql_statement: (skip)
  * @builder: a #GdaSqlBuilder object
  *
  * Creates a new #GdaSqlStatement structure from @builder's contents.
@@ -1039,7 +1039,7 @@ gda_sql_builder_add_param (GdaSqlBuilder *builder, const gchar *param_name, GTyp
 }
 
 /**
- * gda_sql_builder_add_cond:
+ * gda_sql_builder_add_cond: (skip)
  * @builder: a #GdaSqlBuilder object
  * @op: type of condition
  * @op1: the ID of the 1st argument (not 0)
@@ -1083,7 +1083,7 @@ gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, GdaSqlB
 }
 
 /**
- * gda_sql_builder_add_cond_v:
+ * gda_sql_builder_add_cond_v: (skip)
  * @builder: a #GdaSqlBuilder object
  * @op: type of condition
  * @op_ids: (array length=op_ids_size): an array of ID for the arguments (not %0)
@@ -1267,7 +1267,7 @@ typedef struct {
 } BuilderJoin;
 
 /**
- * gda_sql_builder_select_join_targets:
+ * gda_sql_builder_select_join_targets: (skip)
  * @builder: a #GdaSqlBuilder object
  * @left_target_id: the ID of the left target to use (not %0)
  * @right_target_id: the ID of the right target to use (not %0)
@@ -1725,7 +1725,7 @@ gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
 }
 
 /**
- * gda_sql_builder_add_sub_select:
+ * gda_sql_builder_add_sub_select: (skip)
  * @builder: a #GdaSqlBuilder object
  * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  *
@@ -1764,7 +1764,7 @@ gda_sql_builder_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement *sqlst)
 }
 
 /**
- * gda_sql_builder_compound_set_type:
+ * gda_sql_builder_compound_set_type: (skip)
  * @builder: a #GdaSqlBuilder object
  * @compound_type: a type of compound
  *
@@ -1788,7 +1788,7 @@ gda_sql_builder_compound_set_type (GdaSqlBuilder *builder, GdaSqlStatementCompou
 }
 
 /**
- * gda_sql_builder_compound_add_sub_select:
+ * gda_sql_builder_compound_add_sub_select: (skip)
  * @builder: a #GdaSqlBuilder object
  * @sqlst: a pointer to a #GdaSqlStatement, which has to be a SELECT or compound SELECT. This will be copied.
  *
@@ -1946,7 +1946,7 @@ gda_sql_builder_add_case_v (GdaSqlBuilder *builder,
 }
 
 /**
- * gda_sql_builder_export_expression:
+ * gda_sql_builder_export_expression: (skip)
  * @builder: a #GdaSqlBuilder object
  * @id: the ID of the expression to be exported, (must be a valid ID in @builder, not %0)
  *
@@ -1973,7 +1973,7 @@ gda_sql_builder_export_expression (GdaSqlBuilder *builder, GdaSqlBuilderId id)
 }
 
 /**
- * gda_sql_builder_import_expression:
+ * gda_sql_builder_import_expression: (skip)
  * @builder: a #GdaSqlBuilder object
  * @expr: a #GdaSqlExpr obtained using gda_sql_builder_export_expression()
  *
diff --git a/libgda/gda-util.c b/libgda/gda-util.c
index 4805cd6..5b2e9b7 100644
--- a/libgda/gda-util.c
+++ b/libgda/gda-util.c
@@ -888,7 +888,7 @@ dml_statements_check_select_structure (GdaConnection *cnc, GdaSqlStatement *sel_
 }
 
 /**
- * gda_compute_unique_table_row_condition_with_cnc:
+ * gda_compute_unique_table_row_condition_with_cnc:  (skip)
  * @cnc: (allow-none): a #GdaConnection, or %NULL
  * @stsel: a #GdaSqlSelectStatement
  * @mtable: a #GdaMetaTable
@@ -1066,7 +1066,7 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 }
 
 /**
- * gda_compute_unique_table_row_condition:
+ * gda_compute_unique_table_row_condition: (skip)
  * @stsel: a #GdaSqlSelectStatement
  * @mtable: a #GdaMetaTable
  * @require_pk: set to TRUE if a primary key ir required
@@ -1307,7 +1307,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 }
 
 /**
- * gda_compute_select_statement_from_update:
+ * gda_compute_select_statement_from_update: (skip)
  * @update_stmt: an UPDATE statement
  * @error: a place to store errors, or %NULL
  *
@@ -1641,7 +1641,7 @@ static gboolean stmt_rewrite_update_default_keyword (GdaSqlStatementUpdate *upd,
 
 
 /**
- * gda_statement_rewrite_for_default_values:
+ * gda_statement_rewrite_for_default_values: (skip)
  * @stmt: a #GdaStatement object
  * @params: a #GdaSet containing the variable's values to be bound when executing @stmt
  * @remove: set to %TRUE if DEFAULT fields are removed, of %FALSE if the "DEFAULT" keyword is used
diff --git a/libgda/handlers/gda-handler-time.c b/libgda/handlers/gda-handler-time.c
index d9e7996..caa8e48 100644
--- a/libgda/handlers/gda-handler-time.c
+++ b/libgda/handlers/gda-handler-time.c
@@ -426,10 +426,10 @@ handler_compute_locale (GdaHandlerTime *hdl)
 /**
  * gda_handler_time_get_no_locale_str_from_value:
  * @hdl: a #GdaHandlerTime object
- * @value: a GValue value
+ * @value: a #GValue value
  *
- * Retunrs: a new string representing @value without taking the current
- * locele into account
+ * Returns: a new string representing @value without taking the current
+ * locale into account
  */
 gchar *
 gda_handler_time_get_no_locale_str_from_value (GdaHandlerTime *hdl, const GValue *value)
diff --git a/libgda/sql-parser/gda-statement-struct-decl.h b/libgda/sql-parser/gda-statement-struct-decl.h
index 16245cf..9cba130 100644
--- a/libgda/sql-parser/gda-statement-struct-decl.h
+++ b/libgda/sql-parser/gda-statement-struct-decl.h
@@ -99,7 +99,7 @@ typedef enum {
  * Structures identification
  */
 /**
- * GdaSqlAnyPartType:
+ * GdaSqlAnyPartType: (skip)
  * @GDA_SQL_ANY_STMT_SELECT: structure is a #GdaSqlStatementSelect
  * @GDA_SQL_ANY_STMT_INSERT: structure is a #GdaSqlStatementInsert
  * @GDA_SQL_ANY_STMT_UPDATE: structure is a #GdaSqlStatementUpdate
@@ -157,7 +157,7 @@ typedef enum {
 
 
 /**
- * GdaSqlAnyPart:
+ * GdaSqlAnyPart: (skip)
  * @type: type of structure, as a #GdaSqlAnyPartType enum.
  * @parent: pointer to the parent #GdaSqlAnyPart structure
  *
@@ -179,15 +179,15 @@ struct _GdaSqlAnyPart {
 
 /* returns FALSE if a recursive walking should be stopped (mandatory is @error is set) */
 /**
  * GdaSqlForeachFunc:
  * @Param1: the current #GdaSqlAnyPart node
  * @Param2: user data passed to gda_sql_any_part_foreach().
  * @Param3: pointer to a place to store errors
  * @Returns: FALSE if the gda_sql_any_part_foreach() should stop at this point and fail
  *
  * Specifies the type of functions passed to gda_sql_any_part_foreach().
  */
-typedef gboolean (*GdaSqlForeachFunc) (GdaSqlAnyPart *, gpointer, GError **);
+typedef gboolean (*GdaSqlForeachFunc) (GdaSqlAnyPart *part, gpointer data, GError **error);
 
 gboolean gda_sql_any_part_foreach (GdaSqlAnyPart *node, GdaSqlForeachFunc func, gpointer data, GError **error);
 
@@ -179,15 +179,15 @@ struct _GdaSqlAnyPart {
 /* returns FALSE if a recursive walking should be stopped (mandatory is @error is set) */
 /**
- * GdaSqlForeachFunc:
- * @Param1: the current #GdaSqlAnyPart node
- * @Param2: user data passed to gda_sql_any_part_foreach().
- * @Param3: pointer to a place to store errors
+ * GdaSqlForeachFunc: (skip)
+ * @part: the current #GdaSqlAnyPart node
+ * @data: user data passed to gda_sql_any_part_foreach().
+ * @error: pointer to a place to store errors
  * @Returns: FALSE if the gda_sql_any_part_foreach() should stop at this point and fail
  *



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]